==================
BCJ-cffi ChangeLog
==================

All notable changes to this project will be documented in this file.

`Unreleased`_
=============

Added
-----

Changed
-------

Fixed
-----

Deprecated
----------

Removed
-------

Security
--------

`v0.5.1`_
=========

Added
-----
* Release 32bit, MacOS Arm binaries.

Changed
-------
* Improve release CI/CD script.
* Make C header code diet by dropping unused part.


`v0.5.0`_
=========

* Change _*_code() functions to *_code() to expose

`v0.4.0`_
=========

* Add type hint stub.
* Add test configurations.

`v0.3.1`_
=========

* Add ARMT, ARM, SPARC, PPC, IA64 codes.


`v0.3.0`_
=========

* Add x86 BCJFilter class.


.. History links
.. _Unreleased: https://github.com/miurahr/py7zr/compare/v0.5.1...HEAD
.. _v0.5.1: https://github.com/miurahr/py7zr/compare/v0.5.0...v0.5.1
.. _v0.5.0: https://github.com/miurahr/py7zr/compare/v0.4.0...v0.5.0
.. _v0.4.0: https://github.com/miurahr/py7zr/compare/v0.3.1...v0.4.0
.. _v0.3.1: https://github.com/miurahr/py7zr/compare/v0.3.0...v0.3.1
.. _v0.3.0: https://github.com/miurahr/py7zr/compare/v0.1.0...v0.3.0
